<template>
  <b-modal
    :title="title"
    ref="myModalRef"
    ok-title="保存"
    @ok="handleOk"
    @cancel="clearName"
    cancel-title="取消"
  >
    <div>
      <PersonnelTree
          ref="tree"
          :data="treeData"
          :isOpenAll="false"
          :currentId="currentId"
          @currentNode="currentNode"
        />
    </div>
  </b-modal>
</template>

<script>
import PersonnelTree from '@/pages/Personnel/component/PersonnelTree'
export default {
  props: {
    title: String,
    item: Object,
    treeData: {
      default: []
    }
  },
  data: () => ({
    name: '',
    currentOrgItem: null,
    currentId: ''
  }),
  methods: {
    // * 打开modal
    showModel() {
      this.$refs.myModalRef.show()
      this.$nextTick(() => {
        this.reView(this.item)
      })
    },
    hideModel() {
      this.$refs.myModalRef.hide()
    },
    // * 组织机构数点击回调
    currentNode(node) {
      this.currentOrgItem = node
      this.currentId = node.id
    },
    // 回显
    reView(item) {
      if (item) {
        this.currentOrgItem = item
        this.currentId = item.id
        /* 设置选中项 */
        this.$refs.tree.setCurrentKey(item.id)
      } else {
        this.currentOrgItem = null
        this.currentId = ''
        /*  清空  */
        this.$refs.tree.removeCurrentNode()
      }
    },
    // * 提交表单
    handleOk(e) {
      e.preventDefault()
      if (!this.currentOrgItem) {
        this.$toast({
          type: 'error',
          message: '请输组织机构'
        })
        return
      }
      this.$emit('submit', {
        node: this.currentOrgItem,
        id: this.currentId
      })
    },
    // * 取消
    clearName() {}
  },
  components: {
    PersonnelTree
  }
}
</script>
